@@ -1,4 +1,6 @@
-ARABIC_CHARS = "عيئیتطهءنقفإظىرحكةوآؤضسخألذدصثجمزشغبا"
+# -*- coding: utf-8 -*-
+
+ARABIC_CHARS = "دجحإﻹﻷأآﻵخهعغفقثصضذطكمنتالبيسشظزوةىﻻرؤءئ"
 HARAKAT_MAIN = [
     "\u064b",  # Fathatan
     "\u064c",  # Dammatan
@@ -9,12 +11,17 @@ HARAKAT_MAIN = [
     "\u0651",  # Shadda
     "\u0652",  # Sukun
 ]
-ALEF_CHARS = "إأٱآاى" + "\u0670"  # Arabic Letter Superscript Alef
+TANWEEN = HARAKAT_MAIN[0]
+ALEF_CHARS = "إأٱآا" + "\u0670"  # Arabic Letter Superscript Alef
 NORMAL_ALEF = "ا"
+TAH_MARBOTA = "ة"
+HA = "ه"
+ALEF_MAKSORA = "ى"
+YA = "ي"
 HAMZA_CHARS = "ءؤئ" + "\u0655\u0656"  # Arabic Hamza Above and Below
 NORMAL_HAMZA = "ء"
 LAM_ALEF_COMBINED = [
-    "\ufef9",  # Lam Alef
+    "\ufefb",  # Lam Alef
     "\ufef7",  # Lam Alef Hamza Above
     "\ufef9",  # Lam Alef Hamza Below
     "\ufef5",  # Lam Alef Madda Above
