@@ -1,3 +1,4 @@
+from typing import List
 from xinaprocessor.constants import *
 import re
 import emoji
@@ -23,12 +24,14 @@ def remove_hashtags(text: str):
 
 
 def remove_links(text: str):
-    return re.sub("http[s]?://\S+", "", text)
+    return re.sub("http[s]?://\S+|[wW]{3,}[\S/\?=\.&]+", "", text)
 
 
 def remove_mentions(text: str):
-    return re.sub(r"@.*?(?=\s)", "", text)
+    return re.sub(r" @[\w_]+ | @[\w_]+|^@[\w_]+ ", " ", text)
 
+def remove_emails(text: str):
+    return re.sub(r"\S+@\S+", "", text)
 
 def contains_single_char(text: str):
     return True if re.search(r"(?:^| )\w(?:$| )", text) else False
@@ -37,6 +40,8 @@ def contains_single_char(text: str):
 def contains_persian(text: str):
     return True if re.search(r"[\uFB50-\uFB9F{}]".format(''.join(PERSIAN_UNIQUE_CHARS)), text) else False
 
+def contains_english(text: str):
+    return True if re.search(r"[A-Za-z]", text) else False
 
 def remove_single_char_space_before(text: str):
     return re.sub(r"(?:^| )(\w)(?:$| )", r"\1 ", text).strip()
@@ -46,7 +51,17 @@ def remove_single_char_space_after(text: str):
     return re.sub(r"(?:^| )(\w)(?:$| )", r" \1", text).strip()
 
 
-def multi_replace(keys, values, text):
+def multi_replace(keys: List[str], values: List[str], text: str):
+    """Replace each item in keys with the corresponding item in values in the input text
+
+    Args:
+        keys (List[str]): a list of strings to be replaces
+        values (List[str]): list of strings with same length of keys to with values to be replaced with
+        text (str): input text to apply replacements on
+
+    Returns:
+        str: text with strings in keys replaced with corresponding strings in values
+    """
     exp = "|".join(map(re.escape, keys))
     def func(match): return values[keys.index(match.group(0))]
     return re.sub(exp, func, text)
@@ -64,6 +79,13 @@ def replace_repeated_chars(text: str, repeated=1, keep_char=1):
     pattern = r"(.)\1{}".format(f"{{{repeated-1},}}")
     return re.sub(pattern, r"\1" * keep_char, text)
 
+def replace_except(text: str, keep_symbols: str, replace_by: str) -> str:
+    return re.sub(f"[^{keep_symbols}]", replace_by, text)
+
+def contains_repeated_chars(text: str, repeated=1):
+    pattern = r"(.)\1{}".format(f"{{{repeated-1},}}")
+    return True if re.search(pattern, text) else False
+
 
 def train_test_split(x: list, test_size: float, random_seed=None):
     assert test_size > 0.0 and test_size < 1.0, "test size sould be between 0 and 1"
@@ -94,11 +116,15 @@ def arabic_to_transliteration(text: str):
     return text
 
 
-def str_count_words_frequency(text: str, sep=" "):
-    frequency = Counter(text.split(sep))
-    return frequency
+def str_count_frequency(text: str, sep= " ", word_level= True):
+    if word_level:
+        return Counter(text.split(sep))
+    return Counter(text)
 
 
-def doc_count_words_frequency(texts: list, split_by=" "):
+def doc_count_frequency(texts: list, split_by= " ", word_level= True):
     text = split_by.join(texts)
-    return str_count_words_frequency(text, split_by=split_by)
+    return str_count_frequency(text, sep= split_by, word_level= word_level)
+
+def swap_tanween_alef(text: str):
+    return text.replace(TANWEEN + NORMAL_ALEF, NORMAL_ALEF + TANWEEN)
\ No newline at end of file
